==> v1.0.0.zip: cost-benefit-projection/admin/views/intervention/tmpl/edit.php <==
<?php
/*----------------------------------------------------------------------------------|  www.giz.de  |----/
	Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb 
/-------------------------------------------------------------------------------------------------------/

	@version		3.0.8
	@build			1st December, 2015
	@created		15th June, 2012
	@package		Cost Benefit Projection
	@subpackage		edit.php
	@author			Llewellyn van der Merwe <http://www.vdm.io>	
	@owner			Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb
	@copyright		Copyright (C) 2015. All Rights Reserved
	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
	
/-------------------------------------------------------------------------------------------------------/
	Cost Benefit Projection Tool.
/------------------------------------------------------------------------------------------------------*/

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

JHtml::addIncludePath(JPATH_COMPONENT.'/helpers/html');
JHtml::_('behavior.tooltip');
JHtml::_('behavior.formvalidation');
JHtml::_('formbehavior.chosen', 'select');
JHtml::_('behavior.keepalive');
$componentParams = JComponentHelper::getParams('com_costbenefitprojection');
?>

<form action="<?php echo JRoute::_('index.php?option=com_costbenefitprojection&layout=edit&id='.(int) $this->item->id.$this->referral); ?>" method="post" name="adminForm" id="adminForm" class="form-validate" enctype="multipart/form-data">

	<?php echo JLayoutHelper::render('intervention.details_above', $this); ?><div class="form-horizontal">

	<?php echo JHtml::_('bootstrap.startTabSet', 'interventionTab', array('active' => 'details')); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'details', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_DETAILS', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
		</div>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.details_fullwidth', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'settings', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_SETTINGS', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.settings_left', $this); ?>
			</div>
		</div>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.settings_fullwidth', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'publishing', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_PUBLISHING', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span6">
				<?php echo JLayoutHelper::render('intervention.publishing', $this); ?>
			</div>
			<div class="span6">
				<?php echo JLayoutHelper::render('intervention.publlshing', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php if ($this->canDo->get('core.admin')) : ?>
	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'permissions', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_PERMISSION', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<fieldset class="adminform">
					<div class="adminformlist">
					<?php foreach ($this->form->getFieldset('accesscontrol') as $field): ?>
						<div>
							<?php echo $field->label; echo $field->input;?>
						</div>
						<div class="clearfix"></div>
					<?php endforeach; ?>
					</div>
				</fieldset>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>
	<?php endif; ?>

	<?php echo JHtml::_('bootstrap.endTabSet'); ?>

	<div>
		<input type="hidden" name="task" value="intervention.edit" />
		<?php echo JHtml::_('form.token'); ?>
	</div>
</div>

<div class="clearfix"></div>
<?php echo JLayoutHelper::render('intervention.details_under', $this); ?>
</form>

<script type="text/javascript">

// #jform_type listeners for type_NqgeyPG function
jQuery('#jform_type').on('keyup',function()
{
	var type_NqgeyPG = jQuery("#jform_type input[type='radio']:checked").val();
	NqgeyPG(type_NqgeyPG);

});
jQuery('#adminForm').on('change', '#jform_type',function (e)
{
	e.preventDefault();
	var type_NqgeyPG = jQuery("#jform_type input[type='radio']:checked").val();
	NqgeyPG(type_NqgeyPG);

});

// #jform_type listeners for type_oEwwRnj function
jQuery('#jform_type').on('keyup',function()
{
	var type_oEwwRnj = jQuery("#jform_type input[type='radio']:checked").val();
	oEwwRnj(type_oEwwRnj);

});
jQuery('#adminForm').on('change', '#jform_type',function (e)
{
	e.preventDefault();
	var type_oEwwRnj = jQuery("#jform_type input[type='radio']:checked").val();
	oEwwRnj(type_oEwwRnj);

});


jQuery('#adminForm').on('change', '#jform_interventions',function (e)
{
	e.preventDefault();
	var cluster = jQuery("#jform_interventions").val();
	getClusterData(cluster,'jform_interventions');

});

jQuery('#adminForm').on('change', '.clusterintervention',function (e)
{
	jQuery('.clusterintervention').keyup(function () { 
		this.value = this.value.replace(/[^0-9-& \.]/g,'');
	});
	changeFieldValue(this.id,this.value);

});

jQuery('input.form-field-repeatable').on('value-update', function(e, value){
	if (value)
	{
		getBuildTable(value,e.currentTarget.id,'ne');
	}
});

jQuery('input.form-field-repeatable').on('row-add', function(e, row) {
	setSelection();
	updateSelection(row);
});

var causerisk = new Array;
function setSelection()
{
	causerisk.length = 0;
	<?php $fieldNrs = range(1,99,1); ?>
	<?php foreach($fieldNrs as $fieldNr): ?>
	// get options
	var causerisk_<?php echo $fieldNr ?> = jQuery("#jform_intervention_fields_causerisk-<?php echo $fieldNr ?> option:selected").val();
	if (causerisk_<?php echo $fieldNr ?>)
	{
		causerisk.push(causerisk_<?php echo $fieldNr ?>);
	}
	<?php endforeach; ?>
}
</script>

==> v3.2.0.zip: cost-benefit-projection/admin/views/intervention/tmpl/edit.php <==
<?php
/*----------------------------------------------------------------------------------|  www.giz.de  |----/
	Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb 
/-------------------------------------------------------------------------------------------------------/

	@version		3.2.0
	@build			12th January, 2016
	@created		15th June, 2012
	@package		Cost Benefit Projection
	@subpackage		edit.php
	@author			Llewellyn van der Merwe <http://www.vdm.io>	
	@owner			Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb
	@copyright		Copyright (C) 2015. All Rights Reserved
	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
	
/-------------------------------------------------------------------------------------------------------/
	Cost Benefit Projection Tool.
/------------------------------------------------------------------------------------------------------*/

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

JHtml::addIncludePath(JPATH_COMPONENT.'/helpers/html');
JHtml::_('behavior.tooltip');
JHtml::_('behavior.formvalidation');
JHtml::_('formbehavior.chosen', 'select');
JHtml::_('behavior.keepalive');
$componentParams = JComponentHelper::getParams('com_costbenefitprojection');
?>

<form action="<?php echo JRoute::_('index.php?option=com_costbenefitprojection&layout=edit&id='.(int) $this->item->id.$this->referral); ?>" method="post" name="adminForm" id="adminForm" class="form-validate" enctype="multipart/form-data">

	<?php echo JLayoutHelper::render('intervention.details_above', $this); ?><div class="form-horizontal">

	<?php echo JHtml::_('bootstrap.startTabSet', 'interventionTab', array('active' => 'details')); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'details', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_DETAILS', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
		</div>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.details_fullwidth', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'settings', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_SETTINGS', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.settings_left', $this); ?>
			</div>
		</div>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<?php echo JLayoutHelper::render('intervention.settings_fullwidth', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'publishing', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_PUBLISHING', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span6">
				<?php echo JLayoutHelper::render('intervention.publishing', $this); ?>
			</div>
			<div class="span6">
				<?php echo JLayoutHelper::render('intervention.publlshing', $this); ?>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>

	<?php if ($this->canDo->get('core.admin')) : ?>
	<?php echo JHtml::_('bootstrap.addTab', 'interventionTab', 'permissions', JText::_('COM_COSTBENEFITPROJECTION_INTERVENTION_PERMISSION', true)); ?>
		<div class="row-fluid form-horizontal-desktop">
			<div class="span12">
				<fieldset class="adminform">
					<div class="adminformlist">
					<?php foreach ($this->form->getFieldset('accesscontrol') as $field): ?>
						<div>
							<?php echo $field->label; echo $field->input;?>
						</div>
						<div class="clearfix"></div>
					<?php endforeach; ?>
					</div>
				</fieldset>
			</div>
		</div>
	<?php echo JHtml::_('bootstrap.endTab'); ?>
	<?php endif; ?>

	<?php echo JHtml::_('bootstrap.endTabSet'); ?>

	<div>
		<input type="hidden" name="task" value="intervention.edit" />
		<?php echo JHtml::_('form.token'); ?>
	</div>
</div>

<div class="clearfix"></div>
<?php echo JLayoutHelper::render('intervention.details_under', $this); ?>
</form>

<script type="text/javascript">

// #jform_type listeners for type_XCAjMWF function
jQuery('#jform_type').on('keyup',function()
{
	var type_XCAjMWF = jQuery("#jform_type input[type='radio']:checked").val();
	XCAjMWF(type_XCAjMWF);

});
jQuery('#adminForm').on('change', '#jform_type',function (e)
{
	e.preventDefault();
	var type_XCAjMWF = jQuery("#jform_type input[type='radio']:checked").val();
	XCAjMWF(type_XCAjMWF);

});

// #jform_type listeners for type_MmytgLk function
jQuery('#jform_type').on('keyup',function()
{
	var type_MmytgLk = jQuery("#jform_type input[type='radio']:checked").val();
	MmytgLk(type_MmytgLk);

});
jQuery('#adminForm').on('change', '#jform_type',function (e)
{
	e.preventDefault();
	var type_MmytgLk = jQuery("#jform_type input[type='radio']:checked").val();
	MmytgLk(type_MmytgLk);

});


jQuery('#adminForm').on('change', '#jform_interventions',function (e)
{
	e.preventDefault();
	var cluster = jQuery("#jform_interventions").val();
	getClusterData(cluster,'jform_interventions');

});

jQuery('#adminForm').on('change', '.clusterintervention',function (e)
{
	jQuery('.clusterintervention').keyup(function () { 
		this.value = this.value.replace(/[^0-9-& \.]/g,'');
	});
	changeFieldValue(this.id,this.value);

});

jQuery('input.form-field-repeatable').on('value-update', function(e, value){
	if (value)
	{
		getBuildTable(value,e.currentTarget.id,'ne');
	}
});

jQuery('input.form-field-repeatable').on('row-add', function(e, row) {
	setSelection();
	updateSelection(row);
});

var causerisk = new Array;
function setSelection()
{
	causerisk.length = 0;
	<?php $fieldNrs = range(1,99,1); ?>
	<?php foreach($fieldNrs as $fieldNr): ?>
	// get options
	var causerisk_<?php echo $fieldNr ?> = jQuery("#jform_intervention_fields_causerisk-<?php echo $fieldNr ?> option:selected").val();
	if (causerisk_<?php echo $fieldNr ?>)
	{
		causerisk.push(causerisk_<?php echo $fieldNr ?>);
	}
	<?php endforeach; ?>
}
</script>
